:py:mod:`piel.integration.cocotb_sax`
=====================================

.. py:module:: piel.integration.cocotb_sax

.. autoapi-nested-parse::

   The goal of implementing this integration is to enable co-simulation of photonic state evolution based on the
   electronic test function or logical state implemented.
